@@ -123,10 +123,10 @@ class Renderer(base.Renderer):
     @memoize
     def _data(self):
         count = self.data.count
-        lastHour = tuple(self.reports.viewsLastHour()[:count])
-        lastDay = tuple(self.reports.viewsLastDay()[:count])
-        lastWeek = tuple(self.reports.viewsLastWeek()[:count])
-        lastMonth = tuple(self.reports.viewsLastMonth()[:count])
+        lastHour = self.data.showLastHour and tuple(self.reports.viewsLastHour()[:count])
+        lastDay = self.data.showLastDay and tuple(self.reports.viewsLastDay()[:count])
+        lastWeek = self.data.showLastWeek and tuple(self.reports.viewsLastWeek()[:count])
+        lastMonth = self.data.showLastMonth and tuple(self.reports.viewsLastMonth()[:count])
         
         return {'lastHour':lastHour, 
                 'lastDay':lastDay,
