@@ -4,7 +4,7 @@ from datetime import datetime
 from datetime import timedelta
 
 from zope.testing import doctestunit
-from zope.component import testing
+from zope.component import testing, queryUtility
 from Testing import ZopeTestCase as ztc
 
 from Products.Five import zcml
@@ -21,8 +21,15 @@ from sc.social.viewcounter.pageview import SCOPED_SESSION_NAME
 from sc.social.viewcounter.pageview import session
 from sc.social.viewcounter.pageview import PageView
 
+from zope.app.cache.interfaces.ram import IRAMCache
+
 import sc.social.viewcounter
 
+def InvalidateCache(function_name):
+    cache = queryUtility(IRAMCache)
+    if cache:
+        cache.invalidate(function_name)
+
 @onsetup
 def setup_product():
     fiveconfigure.debug_mode = True
@@ -69,8 +76,12 @@ class TestCase(ptc.PloneTestCase):
         
         return objects
         
+    def invalidateReportCache(self):
+        """Invalidate report cache
+        """
+        InvalidateCache('sc.social.viewcounter.browser.viewcounter._reportPageViews')
     
-    def populateViewCounter(self,cleanBefore=False):
+    def populateViewCounter(self,cleanBefore=False, periods=[],invalidate=True):
         ''' Populate viewcounter database
             in order to have data for this test
         '''
@@ -90,7 +101,8 @@ class TestCase(ptc.PloneTestCase):
         user_name = 'foo'
         user_ip = '42.42.42.42'
         # reports we should check against
-        periods = ['lastHour','lastDay','lastWeek','lastMonth']
+        if not periods:
+            periods = ['lastHour','lastDay','lastWeek','lastMonth']
         for period in periods:
             # We will distribute the same ammount of access within each time
             # period, so it's possible to 
@@ -113,9 +125,10 @@ class TestCase(ptc.PloneTestCase):
                     dt, pv = access
                     pv.access_datetime = dt
                     testSession.add(pv)
-        
-        
-        
+        if invalidate:
+            # We invalidate the cache to continue the tests
+            self.invalidateReportCache()
+    
     class layer(PloneSite):
 
 
@@ -142,6 +155,10 @@ def test_suite():
             'docs/integration.txt', package='sc.social.viewcounter',
             test_class=TestCase,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE),
+        ztc.ZopeDocFileSuite(
+            'docs/caching.txt', package='sc.social.viewcounter',
+            test_class=TestCase,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE),
         ztc.ZopeDocFileSuite(
             'docs/portlet.txt', package='sc.social.viewcounter',
             test_class=TestCase,
